# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *
from ._inputs import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_kubernetes.admissionregistration as __admissionregistration
    admissionregistration = __admissionregistration
    import pulumi_kubernetes.apiextensions as __apiextensions
    apiextensions = __apiextensions
    import pulumi_kubernetes.apiregistration as __apiregistration
    apiregistration = __apiregistration
    import pulumi_kubernetes.apps as __apps
    apps = __apps
    import pulumi_kubernetes.auditregistration as __auditregistration
    auditregistration = __auditregistration
    import pulumi_kubernetes.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumi_kubernetes.batch as __batch
    batch = __batch
    import pulumi_kubernetes.certificates as __certificates
    certificates = __certificates
    import pulumi_kubernetes.coordination as __coordination
    coordination = __coordination
    import pulumi_kubernetes.core as __core
    core = __core
    import pulumi_kubernetes.discovery as __discovery
    discovery = __discovery
    import pulumi_kubernetes.events as __events
    events = __events
    import pulumi_kubernetes.extensions as __extensions
    extensions = __extensions
    import pulumi_kubernetes.flowcontrol as __flowcontrol
    flowcontrol = __flowcontrol
    import pulumi_kubernetes.helm as __helm
    helm = __helm
    import pulumi_kubernetes.kustomize as __kustomize
    kustomize = __kustomize
    import pulumi_kubernetes.meta as __meta
    meta = __meta
    import pulumi_kubernetes.networking as __networking
    networking = __networking
    import pulumi_kubernetes.node as __node
    node = __node
    import pulumi_kubernetes.policy as __policy
    policy = __policy
    import pulumi_kubernetes.rbac as __rbac
    rbac = __rbac
    import pulumi_kubernetes.resource as __resource
    resource = __resource
    import pulumi_kubernetes.scheduling as __scheduling
    scheduling = __scheduling
    import pulumi_kubernetes.settings as __settings
    settings = __settings
    import pulumi_kubernetes.storage as __storage
    storage = __storage
    import pulumi_kubernetes.storagemigration as __storagemigration
    storagemigration = __storagemigration
    import pulumi_kubernetes.yaml as __yaml
    yaml = __yaml
else:
    admissionregistration = _utilities.lazy_import('pulumi_kubernetes.admissionregistration')
    apiextensions = _utilities.lazy_import('pulumi_kubernetes.apiextensions')
    apiregistration = _utilities.lazy_import('pulumi_kubernetes.apiregistration')
    apps = _utilities.lazy_import('pulumi_kubernetes.apps')
    auditregistration = _utilities.lazy_import('pulumi_kubernetes.auditregistration')
    autoscaling = _utilities.lazy_import('pulumi_kubernetes.autoscaling')
    batch = _utilities.lazy_import('pulumi_kubernetes.batch')
    certificates = _utilities.lazy_import('pulumi_kubernetes.certificates')
    coordination = _utilities.lazy_import('pulumi_kubernetes.coordination')
    core = _utilities.lazy_import('pulumi_kubernetes.core')
    discovery = _utilities.lazy_import('pulumi_kubernetes.discovery')
    events = _utilities.lazy_import('pulumi_kubernetes.events')
    extensions = _utilities.lazy_import('pulumi_kubernetes.extensions')
    flowcontrol = _utilities.lazy_import('pulumi_kubernetes.flowcontrol')
    helm = _utilities.lazy_import('pulumi_kubernetes.helm')
    kustomize = _utilities.lazy_import('pulumi_kubernetes.kustomize')
    meta = _utilities.lazy_import('pulumi_kubernetes.meta')
    networking = _utilities.lazy_import('pulumi_kubernetes.networking')
    node = _utilities.lazy_import('pulumi_kubernetes.node')
    policy = _utilities.lazy_import('pulumi_kubernetes.policy')
    rbac = _utilities.lazy_import('pulumi_kubernetes.rbac')
    resource = _utilities.lazy_import('pulumi_kubernetes.resource')
    scheduling = _utilities.lazy_import('pulumi_kubernetes.scheduling')
    settings = _utilities.lazy_import('pulumi_kubernetes.settings')
    storage = _utilities.lazy_import('pulumi_kubernetes.storage')
    storagemigration = _utilities.lazy_import('pulumi_kubernetes.storagemigration')
    yaml = _utilities.lazy_import('pulumi_kubernetes.yaml')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "kubernetes",
  "mod": "admissionregistration.k8s.io/v1",
  "fqn": "pulumi_kubernetes.admissionregistration.v1",
  "classes": {
   "kubernetes:admissionregistration.k8s.io/v1:MutatingWebhookConfiguration": "MutatingWebhookConfiguration",
   "kubernetes:admissionregistration.k8s.io/v1:MutatingWebhookConfigurationList": "MutatingWebhookConfigurationList",
   "kubernetes:admissionregistration.k8s.io/v1:MutatingWebhookConfigurationPatch": "MutatingWebhookConfigurationPatch",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingAdmissionPolicy": "ValidatingAdmissionPolicy",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingAdmissionPolicyBinding": "ValidatingAdmissionPolicyBinding",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingAdmissionPolicyBindingList": "ValidatingAdmissionPolicyBindingList",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingAdmissionPolicyBindingPatch": "ValidatingAdmissionPolicyBindingPatch",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingAdmissionPolicyList": "ValidatingAdmissionPolicyList",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingAdmissionPolicyPatch": "ValidatingAdmissionPolicyPatch",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingWebhookConfiguration": "ValidatingWebhookConfiguration",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingWebhookConfigurationList": "ValidatingWebhookConfigurationList",
   "kubernetes:admissionregistration.k8s.io/v1:ValidatingWebhookConfigurationPatch": "ValidatingWebhookConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "admissionregistration.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.admissionregistration.v1alpha1",
  "classes": {
   "kubernetes:admissionregistration.k8s.io/v1alpha1:MutatingAdmissionPolicy": "MutatingAdmissionPolicy",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:MutatingAdmissionPolicyBinding": "MutatingAdmissionPolicyBinding",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:MutatingAdmissionPolicyBindingList": "MutatingAdmissionPolicyBindingList",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:MutatingAdmissionPolicyBindingPatch": "MutatingAdmissionPolicyBindingPatch",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:MutatingAdmissionPolicyList": "MutatingAdmissionPolicyList",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:MutatingAdmissionPolicyPatch": "MutatingAdmissionPolicyPatch",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:ValidatingAdmissionPolicy": "ValidatingAdmissionPolicy",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:ValidatingAdmissionPolicyBinding": "ValidatingAdmissionPolicyBinding",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:ValidatingAdmissionPolicyBindingList": "ValidatingAdmissionPolicyBindingList",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:ValidatingAdmissionPolicyBindingPatch": "ValidatingAdmissionPolicyBindingPatch",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:ValidatingAdmissionPolicyList": "ValidatingAdmissionPolicyList",
   "kubernetes:admissionregistration.k8s.io/v1alpha1:ValidatingAdmissionPolicyPatch": "ValidatingAdmissionPolicyPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "admissionregistration.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.admissionregistration.v1beta1",
  "classes": {
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingAdmissionPolicy": "MutatingAdmissionPolicy",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingAdmissionPolicyBinding": "MutatingAdmissionPolicyBinding",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingAdmissionPolicyBindingList": "MutatingAdmissionPolicyBindingList",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingAdmissionPolicyBindingPatch": "MutatingAdmissionPolicyBindingPatch",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingAdmissionPolicyList": "MutatingAdmissionPolicyList",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingAdmissionPolicyPatch": "MutatingAdmissionPolicyPatch",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingWebhookConfiguration": "MutatingWebhookConfiguration",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingWebhookConfigurationList": "MutatingWebhookConfigurationList",
   "kubernetes:admissionregistration.k8s.io/v1beta1:MutatingWebhookConfigurationPatch": "MutatingWebhookConfigurationPatch",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingAdmissionPolicy": "ValidatingAdmissionPolicy",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingAdmissionPolicyBinding": "ValidatingAdmissionPolicyBinding",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingAdmissionPolicyBindingList": "ValidatingAdmissionPolicyBindingList",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingAdmissionPolicyBindingPatch": "ValidatingAdmissionPolicyBindingPatch",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingAdmissionPolicyList": "ValidatingAdmissionPolicyList",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingAdmissionPolicyPatch": "ValidatingAdmissionPolicyPatch",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingWebhookConfiguration": "ValidatingWebhookConfiguration",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingWebhookConfigurationList": "ValidatingWebhookConfigurationList",
   "kubernetes:admissionregistration.k8s.io/v1beta1:ValidatingWebhookConfigurationPatch": "ValidatingWebhookConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apiextensions.k8s.io/v1",
  "fqn": "pulumi_kubernetes.apiextensions.v1",
  "classes": {
   "kubernetes:apiextensions.k8s.io/v1:CustomResourceDefinition": "CustomResourceDefinition",
   "kubernetes:apiextensions.k8s.io/v1:CustomResourceDefinitionList": "CustomResourceDefinitionList",
   "kubernetes:apiextensions.k8s.io/v1:CustomResourceDefinitionPatch": "CustomResourceDefinitionPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apiextensions.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.apiextensions.v1beta1",
  "classes": {
   "kubernetes:apiextensions.k8s.io/v1beta1:CustomResourceDefinition": "CustomResourceDefinition",
   "kubernetes:apiextensions.k8s.io/v1beta1:CustomResourceDefinitionList": "CustomResourceDefinitionList",
   "kubernetes:apiextensions.k8s.io/v1beta1:CustomResourceDefinitionPatch": "CustomResourceDefinitionPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apiregistration.k8s.io/v1",
  "fqn": "pulumi_kubernetes.apiregistration.v1",
  "classes": {
   "kubernetes:apiregistration.k8s.io/v1:APIService": "APIService",
   "kubernetes:apiregistration.k8s.io/v1:APIServiceList": "APIServiceList",
   "kubernetes:apiregistration.k8s.io/v1:APIServicePatch": "APIServicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apiregistration.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.apiregistration.v1beta1",
  "classes": {
   "kubernetes:apiregistration.k8s.io/v1beta1:APIService": "APIService",
   "kubernetes:apiregistration.k8s.io/v1beta1:APIServiceList": "APIServiceList",
   "kubernetes:apiregistration.k8s.io/v1beta1:APIServicePatch": "APIServicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apps/v1",
  "fqn": "pulumi_kubernetes.apps.v1",
  "classes": {
   "kubernetes:apps/v1:ControllerRevision": "ControllerRevision",
   "kubernetes:apps/v1:ControllerRevisionList": "ControllerRevisionList",
   "kubernetes:apps/v1:ControllerRevisionPatch": "ControllerRevisionPatch",
   "kubernetes:apps/v1:DaemonSet": "DaemonSet",
   "kubernetes:apps/v1:DaemonSetList": "DaemonSetList",
   "kubernetes:apps/v1:DaemonSetPatch": "DaemonSetPatch",
   "kubernetes:apps/v1:Deployment": "Deployment",
   "kubernetes:apps/v1:DeploymentList": "DeploymentList",
   "kubernetes:apps/v1:DeploymentPatch": "DeploymentPatch",
   "kubernetes:apps/v1:ReplicaSet": "ReplicaSet",
   "kubernetes:apps/v1:ReplicaSetList": "ReplicaSetList",
   "kubernetes:apps/v1:ReplicaSetPatch": "ReplicaSetPatch",
   "kubernetes:apps/v1:StatefulSet": "StatefulSet",
   "kubernetes:apps/v1:StatefulSetList": "StatefulSetList",
   "kubernetes:apps/v1:StatefulSetPatch": "StatefulSetPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apps/v1beta1",
  "fqn": "pulumi_kubernetes.apps.v1beta1",
  "classes": {
   "kubernetes:apps/v1beta1:ControllerRevision": "ControllerRevision",
   "kubernetes:apps/v1beta1:ControllerRevisionList": "ControllerRevisionList",
   "kubernetes:apps/v1beta1:ControllerRevisionPatch": "ControllerRevisionPatch",
   "kubernetes:apps/v1beta1:Deployment": "Deployment",
   "kubernetes:apps/v1beta1:DeploymentList": "DeploymentList",
   "kubernetes:apps/v1beta1:DeploymentPatch": "DeploymentPatch",
   "kubernetes:apps/v1beta1:StatefulSet": "StatefulSet",
   "kubernetes:apps/v1beta1:StatefulSetList": "StatefulSetList",
   "kubernetes:apps/v1beta1:StatefulSetPatch": "StatefulSetPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "apps/v1beta2",
  "fqn": "pulumi_kubernetes.apps.v1beta2",
  "classes": {
   "kubernetes:apps/v1beta2:ControllerRevision": "ControllerRevision",
   "kubernetes:apps/v1beta2:ControllerRevisionList": "ControllerRevisionList",
   "kubernetes:apps/v1beta2:ControllerRevisionPatch": "ControllerRevisionPatch",
   "kubernetes:apps/v1beta2:DaemonSet": "DaemonSet",
   "kubernetes:apps/v1beta2:DaemonSetList": "DaemonSetList",
   "kubernetes:apps/v1beta2:DaemonSetPatch": "DaemonSetPatch",
   "kubernetes:apps/v1beta2:Deployment": "Deployment",
   "kubernetes:apps/v1beta2:DeploymentList": "DeploymentList",
   "kubernetes:apps/v1beta2:DeploymentPatch": "DeploymentPatch",
   "kubernetes:apps/v1beta2:ReplicaSet": "ReplicaSet",
   "kubernetes:apps/v1beta2:ReplicaSetList": "ReplicaSetList",
   "kubernetes:apps/v1beta2:ReplicaSetPatch": "ReplicaSetPatch",
   "kubernetes:apps/v1beta2:StatefulSet": "StatefulSet",
   "kubernetes:apps/v1beta2:StatefulSetList": "StatefulSetList",
   "kubernetes:apps/v1beta2:StatefulSetPatch": "StatefulSetPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "auditregistration.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.auditregistration.v1alpha1",
  "classes": {
   "kubernetes:auditregistration.k8s.io/v1alpha1:AuditSink": "AuditSink",
   "kubernetes:auditregistration.k8s.io/v1alpha1:AuditSinkList": "AuditSinkList",
   "kubernetes:auditregistration.k8s.io/v1alpha1:AuditSinkPatch": "AuditSinkPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "autoscaling/v1",
  "fqn": "pulumi_kubernetes.autoscaling.v1",
  "classes": {
   "kubernetes:autoscaling/v1:HorizontalPodAutoscaler": "HorizontalPodAutoscaler",
   "kubernetes:autoscaling/v1:HorizontalPodAutoscalerList": "HorizontalPodAutoscalerList",
   "kubernetes:autoscaling/v1:HorizontalPodAutoscalerPatch": "HorizontalPodAutoscalerPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "autoscaling/v2",
  "fqn": "pulumi_kubernetes.autoscaling.v2",
  "classes": {
   "kubernetes:autoscaling/v2:HorizontalPodAutoscaler": "HorizontalPodAutoscaler",
   "kubernetes:autoscaling/v2:HorizontalPodAutoscalerList": "HorizontalPodAutoscalerList",
   "kubernetes:autoscaling/v2:HorizontalPodAutoscalerPatch": "HorizontalPodAutoscalerPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "autoscaling/v2beta1",
  "fqn": "pulumi_kubernetes.autoscaling.v2beta1",
  "classes": {
   "kubernetes:autoscaling/v2beta1:HorizontalPodAutoscaler": "HorizontalPodAutoscaler",
   "kubernetes:autoscaling/v2beta1:HorizontalPodAutoscalerList": "HorizontalPodAutoscalerList",
   "kubernetes:autoscaling/v2beta1:HorizontalPodAutoscalerPatch": "HorizontalPodAutoscalerPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "autoscaling/v2beta2",
  "fqn": "pulumi_kubernetes.autoscaling.v2beta2",
  "classes": {
   "kubernetes:autoscaling/v2beta2:HorizontalPodAutoscaler": "HorizontalPodAutoscaler",
   "kubernetes:autoscaling/v2beta2:HorizontalPodAutoscalerList": "HorizontalPodAutoscalerList",
   "kubernetes:autoscaling/v2beta2:HorizontalPodAutoscalerPatch": "HorizontalPodAutoscalerPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "batch/v1",
  "fqn": "pulumi_kubernetes.batch.v1",
  "classes": {
   "kubernetes:batch/v1:CronJob": "CronJob",
   "kubernetes:batch/v1:CronJobList": "CronJobList",
   "kubernetes:batch/v1:CronJobPatch": "CronJobPatch",
   "kubernetes:batch/v1:Job": "Job",
   "kubernetes:batch/v1:JobList": "JobList",
   "kubernetes:batch/v1:JobPatch": "JobPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "batch/v1beta1",
  "fqn": "pulumi_kubernetes.batch.v1beta1",
  "classes": {
   "kubernetes:batch/v1beta1:CronJob": "CronJob",
   "kubernetes:batch/v1beta1:CronJobList": "CronJobList",
   "kubernetes:batch/v1beta1:CronJobPatch": "CronJobPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "batch/v2alpha1",
  "fqn": "pulumi_kubernetes.batch.v2alpha1",
  "classes": {
   "kubernetes:batch/v2alpha1:CronJob": "CronJob",
   "kubernetes:batch/v2alpha1:CronJobList": "CronJobList",
   "kubernetes:batch/v2alpha1:CronJobPatch": "CronJobPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "certificates.k8s.io/v1",
  "fqn": "pulumi_kubernetes.certificates.v1",
  "classes": {
   "kubernetes:certificates.k8s.io/v1:CertificateSigningRequest": "CertificateSigningRequest",
   "kubernetes:certificates.k8s.io/v1:CertificateSigningRequestList": "CertificateSigningRequestList",
   "kubernetes:certificates.k8s.io/v1:CertificateSigningRequestPatch": "CertificateSigningRequestPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "certificates.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.certificates.v1alpha1",
  "classes": {
   "kubernetes:certificates.k8s.io/v1alpha1:ClusterTrustBundle": "ClusterTrustBundle",
   "kubernetes:certificates.k8s.io/v1alpha1:ClusterTrustBundleList": "ClusterTrustBundleList",
   "kubernetes:certificates.k8s.io/v1alpha1:ClusterTrustBundlePatch": "ClusterTrustBundlePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "certificates.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.certificates.v1beta1",
  "classes": {
   "kubernetes:certificates.k8s.io/v1beta1:CertificateSigningRequest": "CertificateSigningRequest",
   "kubernetes:certificates.k8s.io/v1beta1:CertificateSigningRequestList": "CertificateSigningRequestList",
   "kubernetes:certificates.k8s.io/v1beta1:CertificateSigningRequestPatch": "CertificateSigningRequestPatch",
   "kubernetes:certificates.k8s.io/v1beta1:ClusterTrustBundle": "ClusterTrustBundle",
   "kubernetes:certificates.k8s.io/v1beta1:ClusterTrustBundleList": "ClusterTrustBundleList",
   "kubernetes:certificates.k8s.io/v1beta1:ClusterTrustBundlePatch": "ClusterTrustBundlePatch",
   "kubernetes:certificates.k8s.io/v1beta1:PodCertificateRequest": "PodCertificateRequest",
   "kubernetes:certificates.k8s.io/v1beta1:PodCertificateRequestList": "PodCertificateRequestList",
   "kubernetes:certificates.k8s.io/v1beta1:PodCertificateRequestPatch": "PodCertificateRequestPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "coordination.k8s.io/v1",
  "fqn": "pulumi_kubernetes.coordination.v1",
  "classes": {
   "kubernetes:coordination.k8s.io/v1:Lease": "Lease",
   "kubernetes:coordination.k8s.io/v1:LeaseList": "LeaseList",
   "kubernetes:coordination.k8s.io/v1:LeasePatch": "LeasePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "coordination.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.coordination.v1alpha1",
  "classes": {
   "kubernetes:coordination.k8s.io/v1alpha1:LeaseCandidate": "LeaseCandidate",
   "kubernetes:coordination.k8s.io/v1alpha1:LeaseCandidateList": "LeaseCandidateList",
   "kubernetes:coordination.k8s.io/v1alpha1:LeaseCandidatePatch": "LeaseCandidatePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "coordination.k8s.io/v1alpha2",
  "fqn": "pulumi_kubernetes.coordination.v1alpha2",
  "classes": {
   "kubernetes:coordination.k8s.io/v1alpha2:LeaseCandidate": "LeaseCandidate",
   "kubernetes:coordination.k8s.io/v1alpha2:LeaseCandidateList": "LeaseCandidateList",
   "kubernetes:coordination.k8s.io/v1alpha2:LeaseCandidatePatch": "LeaseCandidatePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "coordination.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.coordination.v1beta1",
  "classes": {
   "kubernetes:coordination.k8s.io/v1beta1:Lease": "Lease",
   "kubernetes:coordination.k8s.io/v1beta1:LeaseCandidate": "LeaseCandidate",
   "kubernetes:coordination.k8s.io/v1beta1:LeaseCandidateList": "LeaseCandidateList",
   "kubernetes:coordination.k8s.io/v1beta1:LeaseCandidatePatch": "LeaseCandidatePatch",
   "kubernetes:coordination.k8s.io/v1beta1:LeaseList": "LeaseList",
   "kubernetes:coordination.k8s.io/v1beta1:LeasePatch": "LeasePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "core/v1",
  "fqn": "pulumi_kubernetes.core.v1",
  "classes": {
   "kubernetes:core/v1:Binding": "Binding",
   "kubernetes:core/v1:BindingPatch": "BindingPatch",
   "kubernetes:core/v1:ConfigMap": "ConfigMap",
   "kubernetes:core/v1:ConfigMapList": "ConfigMapList",
   "kubernetes:core/v1:ConfigMapPatch": "ConfigMapPatch",
   "kubernetes:core/v1:Endpoints": "Endpoints",
   "kubernetes:core/v1:EndpointsList": "EndpointsList",
   "kubernetes:core/v1:EndpointsPatch": "EndpointsPatch",
   "kubernetes:core/v1:Event": "Event",
   "kubernetes:core/v1:EventList": "EventList",
   "kubernetes:core/v1:EventPatch": "EventPatch",
   "kubernetes:core/v1:LimitRange": "LimitRange",
   "kubernetes:core/v1:LimitRangeList": "LimitRangeList",
   "kubernetes:core/v1:LimitRangePatch": "LimitRangePatch",
   "kubernetes:core/v1:Namespace": "Namespace",
   "kubernetes:core/v1:NamespaceList": "NamespaceList",
   "kubernetes:core/v1:NamespacePatch": "NamespacePatch",
   "kubernetes:core/v1:Node": "Node",
   "kubernetes:core/v1:NodeList": "NodeList",
   "kubernetes:core/v1:NodePatch": "NodePatch",
   "kubernetes:core/v1:PersistentVolume": "PersistentVolume",
   "kubernetes:core/v1:PersistentVolumeClaim": "PersistentVolumeClaim",
   "kubernetes:core/v1:PersistentVolumeClaimList": "PersistentVolumeClaimList",
   "kubernetes:core/v1:PersistentVolumeClaimPatch": "PersistentVolumeClaimPatch",
   "kubernetes:core/v1:PersistentVolumeList": "PersistentVolumeList",
   "kubernetes:core/v1:PersistentVolumePatch": "PersistentVolumePatch",
   "kubernetes:core/v1:Pod": "Pod",
   "kubernetes:core/v1:PodList": "PodList",
   "kubernetes:core/v1:PodPatch": "PodPatch",
   "kubernetes:core/v1:PodTemplate": "PodTemplate",
   "kubernetes:core/v1:PodTemplateList": "PodTemplateList",
   "kubernetes:core/v1:PodTemplatePatch": "PodTemplatePatch",
   "kubernetes:core/v1:ReplicationController": "ReplicationController",
   "kubernetes:core/v1:ReplicationControllerList": "ReplicationControllerList",
   "kubernetes:core/v1:ReplicationControllerPatch": "ReplicationControllerPatch",
   "kubernetes:core/v1:ResourceQuota": "ResourceQuota",
   "kubernetes:core/v1:ResourceQuotaList": "ResourceQuotaList",
   "kubernetes:core/v1:ResourceQuotaPatch": "ResourceQuotaPatch",
   "kubernetes:core/v1:Secret": "Secret",
   "kubernetes:core/v1:SecretList": "SecretList",
   "kubernetes:core/v1:SecretPatch": "SecretPatch",
   "kubernetes:core/v1:Service": "Service",
   "kubernetes:core/v1:ServiceAccount": "ServiceAccount",
   "kubernetes:core/v1:ServiceAccountList": "ServiceAccountList",
   "kubernetes:core/v1:ServiceAccountPatch": "ServiceAccountPatch",
   "kubernetes:core/v1:ServiceList": "ServiceList",
   "kubernetes:core/v1:ServicePatch": "ServicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "discovery.k8s.io/v1",
  "fqn": "pulumi_kubernetes.discovery.v1",
  "classes": {
   "kubernetes:discovery.k8s.io/v1:EndpointSlice": "EndpointSlice",
   "kubernetes:discovery.k8s.io/v1:EndpointSliceList": "EndpointSliceList",
   "kubernetes:discovery.k8s.io/v1:EndpointSlicePatch": "EndpointSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "discovery.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.discovery.v1beta1",
  "classes": {
   "kubernetes:discovery.k8s.io/v1beta1:EndpointSlice": "EndpointSlice",
   "kubernetes:discovery.k8s.io/v1beta1:EndpointSliceList": "EndpointSliceList",
   "kubernetes:discovery.k8s.io/v1beta1:EndpointSlicePatch": "EndpointSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "events.k8s.io/v1",
  "fqn": "pulumi_kubernetes.events.v1",
  "classes": {
   "kubernetes:events.k8s.io/v1:Event": "Event",
   "kubernetes:events.k8s.io/v1:EventList": "EventList",
   "kubernetes:events.k8s.io/v1:EventPatch": "EventPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "events.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.events.v1beta1",
  "classes": {
   "kubernetes:events.k8s.io/v1beta1:Event": "Event",
   "kubernetes:events.k8s.io/v1beta1:EventList": "EventList",
   "kubernetes:events.k8s.io/v1beta1:EventPatch": "EventPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "extensions/v1beta1",
  "fqn": "pulumi_kubernetes.extensions.v1beta1",
  "classes": {
   "kubernetes:extensions/v1beta1:DaemonSet": "DaemonSet",
   "kubernetes:extensions/v1beta1:DaemonSetList": "DaemonSetList",
   "kubernetes:extensions/v1beta1:DaemonSetPatch": "DaemonSetPatch",
   "kubernetes:extensions/v1beta1:Deployment": "Deployment",
   "kubernetes:extensions/v1beta1:DeploymentList": "DeploymentList",
   "kubernetes:extensions/v1beta1:DeploymentPatch": "DeploymentPatch",
   "kubernetes:extensions/v1beta1:Ingress": "Ingress",
   "kubernetes:extensions/v1beta1:IngressList": "IngressList",
   "kubernetes:extensions/v1beta1:IngressPatch": "IngressPatch",
   "kubernetes:extensions/v1beta1:NetworkPolicy": "NetworkPolicy",
   "kubernetes:extensions/v1beta1:NetworkPolicyList": "NetworkPolicyList",
   "kubernetes:extensions/v1beta1:NetworkPolicyPatch": "NetworkPolicyPatch",
   "kubernetes:extensions/v1beta1:PodSecurityPolicy": "PodSecurityPolicy",
   "kubernetes:extensions/v1beta1:PodSecurityPolicyList": "PodSecurityPolicyList",
   "kubernetes:extensions/v1beta1:PodSecurityPolicyPatch": "PodSecurityPolicyPatch",
   "kubernetes:extensions/v1beta1:ReplicaSet": "ReplicaSet",
   "kubernetes:extensions/v1beta1:ReplicaSetList": "ReplicaSetList",
   "kubernetes:extensions/v1beta1:ReplicaSetPatch": "ReplicaSetPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "flowcontrol.apiserver.k8s.io/v1",
  "fqn": "pulumi_kubernetes.flowcontrol.v1",
  "classes": {
   "kubernetes:flowcontrol.apiserver.k8s.io/v1:FlowSchema": "FlowSchema",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1:FlowSchemaList": "FlowSchemaList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1:FlowSchemaPatch": "FlowSchemaPatch",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1:PriorityLevelConfiguration": "PriorityLevelConfiguration",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1:PriorityLevelConfigurationList": "PriorityLevelConfigurationList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1:PriorityLevelConfigurationPatch": "PriorityLevelConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "flowcontrol.apiserver.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.flowcontrol.v1alpha1",
  "classes": {
   "kubernetes:flowcontrol.apiserver.k8s.io/v1alpha1:FlowSchema": "FlowSchema",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1alpha1:FlowSchemaList": "FlowSchemaList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1alpha1:FlowSchemaPatch": "FlowSchemaPatch",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1alpha1:PriorityLevelConfiguration": "PriorityLevelConfiguration",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1alpha1:PriorityLevelConfigurationList": "PriorityLevelConfigurationList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1alpha1:PriorityLevelConfigurationPatch": "PriorityLevelConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "flowcontrol.apiserver.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.flowcontrol.v1beta1",
  "classes": {
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta1:FlowSchema": "FlowSchema",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta1:FlowSchemaList": "FlowSchemaList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta1:FlowSchemaPatch": "FlowSchemaPatch",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta1:PriorityLevelConfiguration": "PriorityLevelConfiguration",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta1:PriorityLevelConfigurationList": "PriorityLevelConfigurationList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta1:PriorityLevelConfigurationPatch": "PriorityLevelConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "flowcontrol.apiserver.k8s.io/v1beta2",
  "fqn": "pulumi_kubernetes.flowcontrol.v1beta2",
  "classes": {
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta2:FlowSchema": "FlowSchema",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta2:FlowSchemaList": "FlowSchemaList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta2:FlowSchemaPatch": "FlowSchemaPatch",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta2:PriorityLevelConfiguration": "PriorityLevelConfiguration",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta2:PriorityLevelConfigurationList": "PriorityLevelConfigurationList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta2:PriorityLevelConfigurationPatch": "PriorityLevelConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "flowcontrol.apiserver.k8s.io/v1beta3",
  "fqn": "pulumi_kubernetes.flowcontrol.v1beta3",
  "classes": {
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta3:FlowSchema": "FlowSchema",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta3:FlowSchemaList": "FlowSchemaList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta3:FlowSchemaPatch": "FlowSchemaPatch",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta3:PriorityLevelConfiguration": "PriorityLevelConfiguration",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta3:PriorityLevelConfigurationList": "PriorityLevelConfigurationList",
   "kubernetes:flowcontrol.apiserver.k8s.io/v1beta3:PriorityLevelConfigurationPatch": "PriorityLevelConfigurationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "helm.sh/v3",
  "fqn": "pulumi_kubernetes.helm.v3",
  "classes": {
   "kubernetes:helm.sh/v3:Release": "Release"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "helm.sh/v4",
  "fqn": "pulumi_kubernetes.helm.v4",
  "classes": {
   "kubernetes:helm.sh/v4:Chart": "Chart"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "kustomize/v2",
  "fqn": "pulumi_kubernetes.kustomize.v2",
  "classes": {
   "kubernetes:kustomize/v2:Directory": "Directory"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "meta/v1",
  "fqn": "pulumi_kubernetes.meta.v1",
  "classes": {
   "kubernetes:meta/v1:Status": "Status",
   "kubernetes:meta/v1:StatusPatch": "StatusPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "networking.k8s.io/v1",
  "fqn": "pulumi_kubernetes.networking.v1",
  "classes": {
   "kubernetes:networking.k8s.io/v1:IPAddress": "IPAddress",
   "kubernetes:networking.k8s.io/v1:IPAddressList": "IPAddressList",
   "kubernetes:networking.k8s.io/v1:IPAddressPatch": "IPAddressPatch",
   "kubernetes:networking.k8s.io/v1:Ingress": "Ingress",
   "kubernetes:networking.k8s.io/v1:IngressClass": "IngressClass",
   "kubernetes:networking.k8s.io/v1:IngressClassList": "IngressClassList",
   "kubernetes:networking.k8s.io/v1:IngressClassPatch": "IngressClassPatch",
   "kubernetes:networking.k8s.io/v1:IngressList": "IngressList",
   "kubernetes:networking.k8s.io/v1:IngressPatch": "IngressPatch",
   "kubernetes:networking.k8s.io/v1:NetworkPolicy": "NetworkPolicy",
   "kubernetes:networking.k8s.io/v1:NetworkPolicyList": "NetworkPolicyList",
   "kubernetes:networking.k8s.io/v1:NetworkPolicyPatch": "NetworkPolicyPatch",
   "kubernetes:networking.k8s.io/v1:ServiceCIDR": "ServiceCIDR",
   "kubernetes:networking.k8s.io/v1:ServiceCIDRList": "ServiceCIDRList",
   "kubernetes:networking.k8s.io/v1:ServiceCIDRPatch": "ServiceCIDRPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "networking.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.networking.v1alpha1",
  "classes": {
   "kubernetes:networking.k8s.io/v1alpha1:ClusterCIDR": "ClusterCIDR",
   "kubernetes:networking.k8s.io/v1alpha1:ClusterCIDRList": "ClusterCIDRList",
   "kubernetes:networking.k8s.io/v1alpha1:ClusterCIDRPatch": "ClusterCIDRPatch",
   "kubernetes:networking.k8s.io/v1alpha1:IPAddress": "IPAddress",
   "kubernetes:networking.k8s.io/v1alpha1:IPAddressList": "IPAddressList",
   "kubernetes:networking.k8s.io/v1alpha1:IPAddressPatch": "IPAddressPatch",
   "kubernetes:networking.k8s.io/v1alpha1:ServiceCIDR": "ServiceCIDR",
   "kubernetes:networking.k8s.io/v1alpha1:ServiceCIDRList": "ServiceCIDRList",
   "kubernetes:networking.k8s.io/v1alpha1:ServiceCIDRPatch": "ServiceCIDRPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "networking.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.networking.v1beta1",
  "classes": {
   "kubernetes:networking.k8s.io/v1beta1:IPAddress": "IPAddress",
   "kubernetes:networking.k8s.io/v1beta1:IPAddressList": "IPAddressList",
   "kubernetes:networking.k8s.io/v1beta1:IPAddressPatch": "IPAddressPatch",
   "kubernetes:networking.k8s.io/v1beta1:Ingress": "Ingress",
   "kubernetes:networking.k8s.io/v1beta1:IngressClass": "IngressClass",
   "kubernetes:networking.k8s.io/v1beta1:IngressClassList": "IngressClassList",
   "kubernetes:networking.k8s.io/v1beta1:IngressClassPatch": "IngressClassPatch",
   "kubernetes:networking.k8s.io/v1beta1:IngressList": "IngressList",
   "kubernetes:networking.k8s.io/v1beta1:IngressPatch": "IngressPatch",
   "kubernetes:networking.k8s.io/v1beta1:ServiceCIDR": "ServiceCIDR",
   "kubernetes:networking.k8s.io/v1beta1:ServiceCIDRList": "ServiceCIDRList",
   "kubernetes:networking.k8s.io/v1beta1:ServiceCIDRPatch": "ServiceCIDRPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "node.k8s.io/v1",
  "fqn": "pulumi_kubernetes.node.v1",
  "classes": {
   "kubernetes:node.k8s.io/v1:RuntimeClass": "RuntimeClass",
   "kubernetes:node.k8s.io/v1:RuntimeClassList": "RuntimeClassList",
   "kubernetes:node.k8s.io/v1:RuntimeClassPatch": "RuntimeClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "node.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.node.v1alpha1",
  "classes": {
   "kubernetes:node.k8s.io/v1alpha1:RuntimeClass": "RuntimeClass",
   "kubernetes:node.k8s.io/v1alpha1:RuntimeClassList": "RuntimeClassList",
   "kubernetes:node.k8s.io/v1alpha1:RuntimeClassPatch": "RuntimeClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "node.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.node.v1beta1",
  "classes": {
   "kubernetes:node.k8s.io/v1beta1:RuntimeClass": "RuntimeClass",
   "kubernetes:node.k8s.io/v1beta1:RuntimeClassList": "RuntimeClassList",
   "kubernetes:node.k8s.io/v1beta1:RuntimeClassPatch": "RuntimeClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "policy/v1",
  "fqn": "pulumi_kubernetes.policy.v1",
  "classes": {
   "kubernetes:policy/v1:PodDisruptionBudget": "PodDisruptionBudget",
   "kubernetes:policy/v1:PodDisruptionBudgetList": "PodDisruptionBudgetList",
   "kubernetes:policy/v1:PodDisruptionBudgetPatch": "PodDisruptionBudgetPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "policy/v1beta1",
  "fqn": "pulumi_kubernetes.policy.v1beta1",
  "classes": {
   "kubernetes:policy/v1beta1:PodDisruptionBudget": "PodDisruptionBudget",
   "kubernetes:policy/v1beta1:PodDisruptionBudgetList": "PodDisruptionBudgetList",
   "kubernetes:policy/v1beta1:PodDisruptionBudgetPatch": "PodDisruptionBudgetPatch",
   "kubernetes:policy/v1beta1:PodSecurityPolicy": "PodSecurityPolicy",
   "kubernetes:policy/v1beta1:PodSecurityPolicyList": "PodSecurityPolicyList",
   "kubernetes:policy/v1beta1:PodSecurityPolicyPatch": "PodSecurityPolicyPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "rbac.authorization.k8s.io/v1",
  "fqn": "pulumi_kubernetes.rbac.v1",
  "classes": {
   "kubernetes:rbac.authorization.k8s.io/v1:ClusterRole": "ClusterRole",
   "kubernetes:rbac.authorization.k8s.io/v1:ClusterRoleBinding": "ClusterRoleBinding",
   "kubernetes:rbac.authorization.k8s.io/v1:ClusterRoleBindingList": "ClusterRoleBindingList",
   "kubernetes:rbac.authorization.k8s.io/v1:ClusterRoleBindingPatch": "ClusterRoleBindingPatch",
   "kubernetes:rbac.authorization.k8s.io/v1:ClusterRoleList": "ClusterRoleList",
   "kubernetes:rbac.authorization.k8s.io/v1:ClusterRolePatch": "ClusterRolePatch",
   "kubernetes:rbac.authorization.k8s.io/v1:Role": "Role",
   "kubernetes:rbac.authorization.k8s.io/v1:RoleBinding": "RoleBinding",
   "kubernetes:rbac.authorization.k8s.io/v1:RoleBindingList": "RoleBindingList",
   "kubernetes:rbac.authorization.k8s.io/v1:RoleBindingPatch": "RoleBindingPatch",
   "kubernetes:rbac.authorization.k8s.io/v1:RoleList": "RoleList",
   "kubernetes:rbac.authorization.k8s.io/v1:RolePatch": "RolePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "rbac.authorization.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.rbac.v1alpha1",
  "classes": {
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:ClusterRole": "ClusterRole",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:ClusterRoleBinding": "ClusterRoleBinding",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:ClusterRoleBindingList": "ClusterRoleBindingList",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:ClusterRoleBindingPatch": "ClusterRoleBindingPatch",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:ClusterRoleList": "ClusterRoleList",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:ClusterRolePatch": "ClusterRolePatch",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:Role": "Role",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:RoleBinding": "RoleBinding",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:RoleBindingList": "RoleBindingList",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:RoleBindingPatch": "RoleBindingPatch",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:RoleList": "RoleList",
   "kubernetes:rbac.authorization.k8s.io/v1alpha1:RolePatch": "RolePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "rbac.authorization.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.rbac.v1beta1",
  "classes": {
   "kubernetes:rbac.authorization.k8s.io/v1beta1:ClusterRole": "ClusterRole",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:ClusterRoleBinding": "ClusterRoleBinding",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:ClusterRoleBindingList": "ClusterRoleBindingList",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:ClusterRoleBindingPatch": "ClusterRoleBindingPatch",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:ClusterRoleList": "ClusterRoleList",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:ClusterRolePatch": "ClusterRolePatch",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:Role": "Role",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:RoleBinding": "RoleBinding",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:RoleBindingList": "RoleBindingList",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:RoleBindingPatch": "RoleBindingPatch",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:RoleList": "RoleList",
   "kubernetes:rbac.authorization.k8s.io/v1beta1:RolePatch": "RolePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "resource.k8s.io/v1",
  "fqn": "pulumi_kubernetes.resource.v1",
  "classes": {
   "kubernetes:resource.k8s.io/v1:DeviceClass": "DeviceClass",
   "kubernetes:resource.k8s.io/v1:DeviceClassList": "DeviceClassList",
   "kubernetes:resource.k8s.io/v1:DeviceClassPatch": "DeviceClassPatch",
   "kubernetes:resource.k8s.io/v1:ResourceClaim": "ResourceClaim",
   "kubernetes:resource.k8s.io/v1:ResourceClaimList": "ResourceClaimList",
   "kubernetes:resource.k8s.io/v1:ResourceClaimPatch": "ResourceClaimPatch",
   "kubernetes:resource.k8s.io/v1:ResourceClaimTemplate": "ResourceClaimTemplate",
   "kubernetes:resource.k8s.io/v1:ResourceClaimTemplateList": "ResourceClaimTemplateList",
   "kubernetes:resource.k8s.io/v1:ResourceClaimTemplatePatch": "ResourceClaimTemplatePatch",
   "kubernetes:resource.k8s.io/v1:ResourceSlice": "ResourceSlice",
   "kubernetes:resource.k8s.io/v1:ResourceSliceList": "ResourceSliceList",
   "kubernetes:resource.k8s.io/v1:ResourceSlicePatch": "ResourceSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "resource.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.resource.v1alpha1",
  "classes": {
   "kubernetes:resource.k8s.io/v1alpha1:PodScheduling": "PodScheduling",
   "kubernetes:resource.k8s.io/v1alpha1:PodSchedulingList": "PodSchedulingList",
   "kubernetes:resource.k8s.io/v1alpha1:PodSchedulingPatch": "PodSchedulingPatch",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClaim": "ResourceClaim",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClaimList": "ResourceClaimList",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClaimPatch": "ResourceClaimPatch",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClaimTemplate": "ResourceClaimTemplate",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClaimTemplateList": "ResourceClaimTemplateList",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClaimTemplatePatch": "ResourceClaimTemplatePatch",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClass": "ResourceClass",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClassList": "ResourceClassList",
   "kubernetes:resource.k8s.io/v1alpha1:ResourceClassPatch": "ResourceClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "resource.k8s.io/v1alpha2",
  "fqn": "pulumi_kubernetes.resource.v1alpha2",
  "classes": {
   "kubernetes:resource.k8s.io/v1alpha2:PodSchedulingContext": "PodSchedulingContext",
   "kubernetes:resource.k8s.io/v1alpha2:PodSchedulingContextList": "PodSchedulingContextList",
   "kubernetes:resource.k8s.io/v1alpha2:PodSchedulingContextPatch": "PodSchedulingContextPatch",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaim": "ResourceClaim",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimList": "ResourceClaimList",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimParameters": "ResourceClaimParameters",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimParametersList": "ResourceClaimParametersList",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimParametersPatch": "ResourceClaimParametersPatch",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimPatch": "ResourceClaimPatch",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimTemplate": "ResourceClaimTemplate",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimTemplateList": "ResourceClaimTemplateList",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClaimTemplatePatch": "ResourceClaimTemplatePatch",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClass": "ResourceClass",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClassList": "ResourceClassList",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClassParameters": "ResourceClassParameters",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClassParametersList": "ResourceClassParametersList",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClassParametersPatch": "ResourceClassParametersPatch",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceClassPatch": "ResourceClassPatch",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceSlice": "ResourceSlice",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceSliceList": "ResourceSliceList",
   "kubernetes:resource.k8s.io/v1alpha2:ResourceSlicePatch": "ResourceSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "resource.k8s.io/v1alpha3",
  "fqn": "pulumi_kubernetes.resource.v1alpha3",
  "classes": {
   "kubernetes:resource.k8s.io/v1alpha3:DeviceClass": "DeviceClass",
   "kubernetes:resource.k8s.io/v1alpha3:DeviceClassList": "DeviceClassList",
   "kubernetes:resource.k8s.io/v1alpha3:DeviceClassPatch": "DeviceClassPatch",
   "kubernetes:resource.k8s.io/v1alpha3:DeviceTaintRule": "DeviceTaintRule",
   "kubernetes:resource.k8s.io/v1alpha3:DeviceTaintRuleList": "DeviceTaintRuleList",
   "kubernetes:resource.k8s.io/v1alpha3:DeviceTaintRulePatch": "DeviceTaintRulePatch",
   "kubernetes:resource.k8s.io/v1alpha3:PodSchedulingContext": "PodSchedulingContext",
   "kubernetes:resource.k8s.io/v1alpha3:PodSchedulingContextList": "PodSchedulingContextList",
   "kubernetes:resource.k8s.io/v1alpha3:PodSchedulingContextPatch": "PodSchedulingContextPatch",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceClaim": "ResourceClaim",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceClaimList": "ResourceClaimList",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceClaimPatch": "ResourceClaimPatch",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceClaimTemplate": "ResourceClaimTemplate",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceClaimTemplateList": "ResourceClaimTemplateList",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceClaimTemplatePatch": "ResourceClaimTemplatePatch",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceSlice": "ResourceSlice",
   "kubernetes:resource.k8s.io/v1alpha3:ResourceSlicePatch": "ResourceSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "resource.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.resource.v1beta1",
  "classes": {
   "kubernetes:resource.k8s.io/v1beta1:DeviceClass": "DeviceClass",
   "kubernetes:resource.k8s.io/v1beta1:DeviceClassList": "DeviceClassList",
   "kubernetes:resource.k8s.io/v1beta1:DeviceClassPatch": "DeviceClassPatch",
   "kubernetes:resource.k8s.io/v1beta1:ResourceClaim": "ResourceClaim",
   "kubernetes:resource.k8s.io/v1beta1:ResourceClaimList": "ResourceClaimList",
   "kubernetes:resource.k8s.io/v1beta1:ResourceClaimPatch": "ResourceClaimPatch",
   "kubernetes:resource.k8s.io/v1beta1:ResourceClaimTemplate": "ResourceClaimTemplate",
   "kubernetes:resource.k8s.io/v1beta1:ResourceClaimTemplateList": "ResourceClaimTemplateList",
   "kubernetes:resource.k8s.io/v1beta1:ResourceClaimTemplatePatch": "ResourceClaimTemplatePatch",
   "kubernetes:resource.k8s.io/v1beta1:ResourceSlice": "ResourceSlice",
   "kubernetes:resource.k8s.io/v1beta1:ResourceSliceList": "ResourceSliceList",
   "kubernetes:resource.k8s.io/v1beta1:ResourceSlicePatch": "ResourceSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "resource.k8s.io/v1beta2",
  "fqn": "pulumi_kubernetes.resource.v1beta2",
  "classes": {
   "kubernetes:resource.k8s.io/v1beta2:DeviceClass": "DeviceClass",
   "kubernetes:resource.k8s.io/v1beta2:DeviceClassList": "DeviceClassList",
   "kubernetes:resource.k8s.io/v1beta2:DeviceClassPatch": "DeviceClassPatch",
   "kubernetes:resource.k8s.io/v1beta2:ResourceClaim": "ResourceClaim",
   "kubernetes:resource.k8s.io/v1beta2:ResourceClaimList": "ResourceClaimList",
   "kubernetes:resource.k8s.io/v1beta2:ResourceClaimPatch": "ResourceClaimPatch",
   "kubernetes:resource.k8s.io/v1beta2:ResourceClaimTemplate": "ResourceClaimTemplate",
   "kubernetes:resource.k8s.io/v1beta2:ResourceClaimTemplateList": "ResourceClaimTemplateList",
   "kubernetes:resource.k8s.io/v1beta2:ResourceClaimTemplatePatch": "ResourceClaimTemplatePatch",
   "kubernetes:resource.k8s.io/v1beta2:ResourceSlice": "ResourceSlice",
   "kubernetes:resource.k8s.io/v1beta2:ResourceSliceList": "ResourceSliceList",
   "kubernetes:resource.k8s.io/v1beta2:ResourceSlicePatch": "ResourceSlicePatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "scheduling.k8s.io/v1",
  "fqn": "pulumi_kubernetes.scheduling.v1",
  "classes": {
   "kubernetes:scheduling.k8s.io/v1:PriorityClass": "PriorityClass",
   "kubernetes:scheduling.k8s.io/v1:PriorityClassList": "PriorityClassList",
   "kubernetes:scheduling.k8s.io/v1:PriorityClassPatch": "PriorityClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "scheduling.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.scheduling.v1alpha1",
  "classes": {
   "kubernetes:scheduling.k8s.io/v1alpha1:PriorityClass": "PriorityClass",
   "kubernetes:scheduling.k8s.io/v1alpha1:PriorityClassList": "PriorityClassList",
   "kubernetes:scheduling.k8s.io/v1alpha1:PriorityClassPatch": "PriorityClassPatch",
   "kubernetes:scheduling.k8s.io/v1alpha1:Workload": "Workload",
   "kubernetes:scheduling.k8s.io/v1alpha1:WorkloadList": "WorkloadList",
   "kubernetes:scheduling.k8s.io/v1alpha1:WorkloadPatch": "WorkloadPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "scheduling.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.scheduling.v1beta1",
  "classes": {
   "kubernetes:scheduling.k8s.io/v1beta1:PriorityClass": "PriorityClass",
   "kubernetes:scheduling.k8s.io/v1beta1:PriorityClassList": "PriorityClassList",
   "kubernetes:scheduling.k8s.io/v1beta1:PriorityClassPatch": "PriorityClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "settings.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.settings.v1alpha1",
  "classes": {
   "kubernetes:settings.k8s.io/v1alpha1:PodPreset": "PodPreset",
   "kubernetes:settings.k8s.io/v1alpha1:PodPresetList": "PodPresetList",
   "kubernetes:settings.k8s.io/v1alpha1:PodPresetPatch": "PodPresetPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "storage.k8s.io/v1",
  "fqn": "pulumi_kubernetes.storage.v1",
  "classes": {
   "kubernetes:storage.k8s.io/v1:CSIDriver": "CSIDriver",
   "kubernetes:storage.k8s.io/v1:CSIDriverList": "CSIDriverList",
   "kubernetes:storage.k8s.io/v1:CSIDriverPatch": "CSIDriverPatch",
   "kubernetes:storage.k8s.io/v1:CSINode": "CSINode",
   "kubernetes:storage.k8s.io/v1:CSINodeList": "CSINodeList",
   "kubernetes:storage.k8s.io/v1:CSINodePatch": "CSINodePatch",
   "kubernetes:storage.k8s.io/v1:CSIStorageCapacity": "CSIStorageCapacity",
   "kubernetes:storage.k8s.io/v1:CSIStorageCapacityList": "CSIStorageCapacityList",
   "kubernetes:storage.k8s.io/v1:CSIStorageCapacityPatch": "CSIStorageCapacityPatch",
   "kubernetes:storage.k8s.io/v1:StorageClass": "StorageClass",
   "kubernetes:storage.k8s.io/v1:StorageClassList": "StorageClassList",
   "kubernetes:storage.k8s.io/v1:StorageClassPatch": "StorageClassPatch",
   "kubernetes:storage.k8s.io/v1:VolumeAttachment": "VolumeAttachment",
   "kubernetes:storage.k8s.io/v1:VolumeAttachmentList": "VolumeAttachmentList",
   "kubernetes:storage.k8s.io/v1:VolumeAttachmentPatch": "VolumeAttachmentPatch",
   "kubernetes:storage.k8s.io/v1:VolumeAttributesClass": "VolumeAttributesClass",
   "kubernetes:storage.k8s.io/v1:VolumeAttributesClassList": "VolumeAttributesClassList",
   "kubernetes:storage.k8s.io/v1:VolumeAttributesClassPatch": "VolumeAttributesClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "storage.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.storage.v1alpha1",
  "classes": {
   "kubernetes:storage.k8s.io/v1alpha1:VolumeAttachment": "VolumeAttachment",
   "kubernetes:storage.k8s.io/v1alpha1:VolumeAttachmentList": "VolumeAttachmentList",
   "kubernetes:storage.k8s.io/v1alpha1:VolumeAttachmentPatch": "VolumeAttachmentPatch",
   "kubernetes:storage.k8s.io/v1alpha1:VolumeAttributesClass": "VolumeAttributesClass",
   "kubernetes:storage.k8s.io/v1alpha1:VolumeAttributesClassList": "VolumeAttributesClassList",
   "kubernetes:storage.k8s.io/v1alpha1:VolumeAttributesClassPatch": "VolumeAttributesClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "storage.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.storage.v1beta1",
  "classes": {
   "kubernetes:storage.k8s.io/v1beta1:CSIDriver": "CSIDriver",
   "kubernetes:storage.k8s.io/v1beta1:CSIDriverList": "CSIDriverList",
   "kubernetes:storage.k8s.io/v1beta1:CSIDriverPatch": "CSIDriverPatch",
   "kubernetes:storage.k8s.io/v1beta1:CSINode": "CSINode",
   "kubernetes:storage.k8s.io/v1beta1:CSINodeList": "CSINodeList",
   "kubernetes:storage.k8s.io/v1beta1:CSINodePatch": "CSINodePatch",
   "kubernetes:storage.k8s.io/v1beta1:CSIStorageCapacity": "CSIStorageCapacity",
   "kubernetes:storage.k8s.io/v1beta1:CSIStorageCapacityList": "CSIStorageCapacityList",
   "kubernetes:storage.k8s.io/v1beta1:CSIStorageCapacityPatch": "CSIStorageCapacityPatch",
   "kubernetes:storage.k8s.io/v1beta1:StorageClass": "StorageClass",
   "kubernetes:storage.k8s.io/v1beta1:StorageClassList": "StorageClassList",
   "kubernetes:storage.k8s.io/v1beta1:StorageClassPatch": "StorageClassPatch",
   "kubernetes:storage.k8s.io/v1beta1:VolumeAttachment": "VolumeAttachment",
   "kubernetes:storage.k8s.io/v1beta1:VolumeAttachmentList": "VolumeAttachmentList",
   "kubernetes:storage.k8s.io/v1beta1:VolumeAttachmentPatch": "VolumeAttachmentPatch",
   "kubernetes:storage.k8s.io/v1beta1:VolumeAttributesClass": "VolumeAttributesClass",
   "kubernetes:storage.k8s.io/v1beta1:VolumeAttributesClassList": "VolumeAttributesClassList",
   "kubernetes:storage.k8s.io/v1beta1:VolumeAttributesClassPatch": "VolumeAttributesClassPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "storagemigration.k8s.io/v1alpha1",
  "fqn": "pulumi_kubernetes.storagemigration.v1alpha1",
  "classes": {
   "kubernetes:storagemigration.k8s.io/v1alpha1:StorageVersionMigration": "StorageVersionMigration",
   "kubernetes:storagemigration.k8s.io/v1alpha1:StorageVersionMigrationList": "StorageVersionMigrationList",
   "kubernetes:storagemigration.k8s.io/v1alpha1:StorageVersionMigrationPatch": "StorageVersionMigrationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "storagemigration.k8s.io/v1beta1",
  "fqn": "pulumi_kubernetes.storagemigration.v1beta1",
  "classes": {
   "kubernetes:storagemigration.k8s.io/v1beta1:StorageVersionMigration": "StorageVersionMigration",
   "kubernetes:storagemigration.k8s.io/v1beta1:StorageVersionMigrationList": "StorageVersionMigrationList",
   "kubernetes:storagemigration.k8s.io/v1beta1:StorageVersionMigrationPatch": "StorageVersionMigrationPatch"
  }
 },
 {
  "pkg": "kubernetes",
  "mod": "yaml/v2",
  "fqn": "pulumi_kubernetes.yaml.v2",
  "classes": {
   "kubernetes:yaml/v2:ConfigFile": "ConfigFile",
   "kubernetes:yaml/v2:ConfigGroup": "ConfigGroup"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "kubernetes",
  "token": "pulumi:providers:kubernetes",
  "fqn": "pulumi_kubernetes",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from ... import _utilities
from . import outputs
from ... import meta as _meta

__all__ = [
    'BasicSchedulingPolicy',
    'BasicSchedulingPolicyPatch',
    'GangSchedulingPolicy',
    'GangSchedulingPolicyPatch',
    'PodGroup',
    'PodGroupPatch',
    'PodGroupPolicy',
    'PodGroupPolicyPatch',
    'PriorityClass',
    'TypedLocalObjectReference',
    'TypedLocalObjectReferencePatch',
    'Workload',
    'WorkloadSpec',
    'WorkloadSpecPatch',
]

@pulumi.output_type
class BasicSchedulingPolicy(dict):
    """
    BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
    """
    def __init__(__self__):
        """
        BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
        """
        pass


@pulumi.output_type
class BasicSchedulingPolicyPatch(dict):
    """
    BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
    """
    def __init__(__self__):
        """
        BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
        """
        pass


@pulumi.output_type
class GangSchedulingPolicy(dict):
    """
    GangSchedulingPolicy defines the parameters for gang scheduling.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "minCount":
            suggest = "min_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GangSchedulingPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GangSchedulingPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GangSchedulingPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 min_count: _builtins.int):
        """
        GangSchedulingPolicy defines the parameters for gang scheduling.

        :param _builtins.int min_count: MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        pulumi.set(__self__, "min_count", min_count)

    @_builtins.property
    @pulumi.getter(name="minCount")
    def min_count(self) -> _builtins.int:
        """
        MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        return pulumi.get(self, "min_count")


@pulumi.output_type
class GangSchedulingPolicyPatch(dict):
    """
    GangSchedulingPolicy defines the parameters for gang scheduling.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "minCount":
            suggest = "min_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GangSchedulingPolicyPatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GangSchedulingPolicyPatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GangSchedulingPolicyPatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 min_count: Optional[_builtins.int] = None):
        """
        GangSchedulingPolicy defines the parameters for gang scheduling.

        :param _builtins.int min_count: MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        if min_count is not None:
            pulumi.set(__self__, "min_count", min_count)

    @_builtins.property
    @pulumi.getter(name="minCount")
    def min_count(self) -> Optional[_builtins.int]:
        """
        MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        return pulumi.get(self, "min_count")


@pulumi.output_type
class PodGroup(dict):
    """
    PodGroup represents a set of pods with a common scheduling policy.
    """
    def __init__(__self__, *,
                 name: _builtins.str,
                 policy: 'outputs.PodGroupPolicy'):
        """
        PodGroup represents a set of pods with a common scheduling policy.

        :param _builtins.str name: Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        :param 'PodGroupPolicyArgs' policy: Policy defines the scheduling policy for this PodGroup.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "policy", policy)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def policy(self) -> 'outputs.PodGroupPolicy':
        """
        Policy defines the scheduling policy for this PodGroup.
        """
        return pulumi.get(self, "policy")


@pulumi.output_type
class PodGroupPatch(dict):
    """
    PodGroup represents a set of pods with a common scheduling policy.
    """
    def __init__(__self__, *,
                 name: Optional[_builtins.str] = None,
                 policy: Optional['outputs.PodGroupPolicyPatch'] = None):
        """
        PodGroup represents a set of pods with a common scheduling policy.

        :param _builtins.str name: Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        :param 'PodGroupPolicyPatchArgs' policy: Policy defines the scheduling policy for this PodGroup.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional['outputs.PodGroupPolicyPatch']:
        """
        Policy defines the scheduling policy for this PodGroup.
        """
        return pulumi.get(self, "policy")


@pulumi.output_type
class PodGroupPolicy(dict):
    """
    PodGroupPolicy defines the scheduling configuration for a PodGroup.
    """
    def __init__(__self__, *,
                 basic: Optional['outputs.BasicSchedulingPolicy'] = None,
                 gang: Optional['outputs.GangSchedulingPolicy'] = None):
        """
        PodGroupPolicy defines the scheduling configuration for a PodGroup.

        :param 'BasicSchedulingPolicyArgs' basic: Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        :param 'GangSchedulingPolicyArgs' gang: Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        if basic is not None:
            pulumi.set(__self__, "basic", basic)
        if gang is not None:
            pulumi.set(__self__, "gang", gang)

    @_builtins.property
    @pulumi.getter
    def basic(self) -> Optional['outputs.BasicSchedulingPolicy']:
        """
        Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        """
        return pulumi.get(self, "basic")

    @_builtins.property
    @pulumi.getter
    def gang(self) -> Optional['outputs.GangSchedulingPolicy']:
        """
        Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        return pulumi.get(self, "gang")


@pulumi.output_type
class PodGroupPolicyPatch(dict):
    """
    PodGroupPolicy defines the scheduling configuration for a PodGroup.
    """
    def __init__(__self__, *,
                 basic: Optional['outputs.BasicSchedulingPolicyPatch'] = None,
                 gang: Optional['outputs.GangSchedulingPolicyPatch'] = None):
        """
        PodGroupPolicy defines the scheduling configuration for a PodGroup.

        :param 'BasicSchedulingPolicyPatchArgs' basic: Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        :param 'GangSchedulingPolicyPatchArgs' gang: Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        if basic is not None:
            pulumi.set(__self__, "basic", basic)
        if gang is not None:
            pulumi.set(__self__, "gang", gang)

    @_builtins.property
    @pulumi.getter
    def basic(self) -> Optional['outputs.BasicSchedulingPolicyPatch']:
        """
        Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        """
        return pulumi.get(self, "basic")

    @_builtins.property
    @pulumi.getter
    def gang(self) -> Optional['outputs.GangSchedulingPolicyPatch']:
        """
        Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        return pulumi.get(self, "gang")


@pulumi.output_type
class PriorityClass(dict):
    """
    DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiVersion":
            suggest = "api_version"
        elif key == "globalDefault":
            suggest = "global_default"
        elif key == "preemptionPolicy":
            suggest = "preemption_policy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PriorityClass. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PriorityClass.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PriorityClass.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 value: _builtins.int,
                 api_version: Optional[_builtins.str] = None,
                 description: Optional[_builtins.str] = None,
                 global_default: Optional[_builtins.bool] = None,
                 kind: Optional[_builtins.str] = None,
                 metadata: Optional['_meta.v1.outputs.ObjectMeta'] = None,
                 preemption_policy: Optional[_builtins.str] = None):
        """
        DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.

        :param _builtins.int value: The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
        :param _builtins.str api_version: APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        :param _builtins.str description: description is an arbitrary string that usually provides guidelines on when this priority class should be used.
        :param _builtins.bool global_default: globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
        :param _builtins.str kind: Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        :param '_meta.v1.ObjectMetaArgs' metadata: Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        :param _builtins.str preemption_policy: PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is alpha-level and is only honored by servers that enable the NonPreemptingPriority feature.
        """
        pulumi.set(__self__, "value", value)
        if api_version is not None:
            pulumi.set(__self__, "api_version", 'scheduling.k8s.io/v1alpha1')
        if description is not None:
            pulumi.set(__self__, "description", description)
        if global_default is not None:
            pulumi.set(__self__, "global_default", global_default)
        if kind is not None:
            pulumi.set(__self__, "kind", 'PriorityClass')
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if preemption_policy is not None:
            pulumi.set(__self__, "preemption_policy", preemption_policy)

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.int:
        """
        The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[_builtins.str]:
        """
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        description is an arbitrary string that usually provides guidelines on when this priority class should be used.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="globalDefault")
    def global_default(self) -> Optional[_builtins.bool]:
        """
        globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
        """
        return pulumi.get(self, "global_default")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[_builtins.str]:
        """
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional['_meta.v1.outputs.ObjectMeta']:
        """
        Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter(name="preemptionPolicy")
    def preemption_policy(self) -> Optional[_builtins.str]:
        """
        PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is alpha-level and is only honored by servers that enable the NonPreemptingPriority feature.
        """
        return pulumi.get(self, "preemption_policy")


@pulumi.output_type
class TypedLocalObjectReference(dict):
    """
    TypedLocalObjectReference allows to reference typed object inside the same namespace.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiGroup":
            suggest = "api_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TypedLocalObjectReference. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TypedLocalObjectReference.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TypedLocalObjectReference.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 kind: _builtins.str,
                 name: _builtins.str,
                 api_group: Optional[_builtins.str] = None):
        """
        TypedLocalObjectReference allows to reference typed object inside the same namespace.

        :param _builtins.str kind: Kind is the type of resource being referenced. It must be a path segment name.
        :param _builtins.str name: Name is the name of resource being referenced. It must be a path segment name.
        :param _builtins.str api_group: APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        """
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "name", name)
        if api_group is not None:
            pulumi.set(__self__, "api_group", api_group)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> _builtins.str:
        """
        Kind is the type of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name is the name of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="apiGroup")
    def api_group(self) -> Optional[_builtins.str]:
        """
        APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        """
        return pulumi.get(self, "api_group")


@pulumi.output_type
class TypedLocalObjectReferencePatch(dict):
    """
    TypedLocalObjectReference allows to reference typed object inside the same namespace.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiGroup":
            suggest = "api_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TypedLocalObjectReferencePatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TypedLocalObjectReferencePatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TypedLocalObjectReferencePatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 api_group: Optional[_builtins.str] = None,
                 kind: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None):
        """
        TypedLocalObjectReference allows to reference typed object inside the same namespace.

        :param _builtins.str api_group: APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        :param _builtins.str kind: Kind is the type of resource being referenced. It must be a path segment name.
        :param _builtins.str name: Name is the name of resource being referenced. It must be a path segment name.
        """
        if api_group is not None:
            pulumi.set(__self__, "api_group", api_group)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="apiGroup")
    def api_group(self) -> Optional[_builtins.str]:
        """
        APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        """
        return pulumi.get(self, "api_group")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[_builtins.str]:
        """
        Kind is the type of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name is the name of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class Workload(dict):
    """
    Workload allows for expressing scheduling constraints that should be used when managing lifecycle of workloads from scheduling perspective, including scheduling, preemption, eviction and other phases.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiVersion":
            suggest = "api_version"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in Workload. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        Workload.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        Workload.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 spec: 'outputs.WorkloadSpec',
                 api_version: Optional[_builtins.str] = None,
                 kind: Optional[_builtins.str] = None,
                 metadata: Optional['_meta.v1.outputs.ObjectMeta'] = None):
        """
        Workload allows for expressing scheduling constraints that should be used when managing lifecycle of workloads from scheduling perspective, including scheduling, preemption, eviction and other phases.

        :param 'WorkloadSpecArgs' spec: Spec defines the desired behavior of a Workload.
        :param _builtins.str api_version: APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        :param _builtins.str kind: Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        :param '_meta.v1.ObjectMetaArgs' metadata: Standard object's metadata. Name must be a DNS subdomain.
        """
        pulumi.set(__self__, "spec", spec)
        if api_version is not None:
            pulumi.set(__self__, "api_version", 'scheduling.k8s.io/v1alpha1')
        if kind is not None:
            pulumi.set(__self__, "kind", 'Workload')
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> 'outputs.WorkloadSpec':
        """
        Spec defines the desired behavior of a Workload.
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[_builtins.str]:
        """
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[_builtins.str]:
        """
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional['_meta.v1.outputs.ObjectMeta']:
        """
        Standard object's metadata. Name must be a DNS subdomain.
        """
        return pulumi.get(self, "metadata")


@pulumi.output_type
class WorkloadSpec(dict):
    """
    WorkloadSpec defines the desired state of a Workload.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "podGroups":
            suggest = "pod_groups"
        elif key == "controllerRef":
            suggest = "controller_ref"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadSpec. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadSpec.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadSpec.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 pod_groups: Sequence['outputs.PodGroup'],
                 controller_ref: Optional['outputs.TypedLocalObjectReference'] = None):
        """
        WorkloadSpec defines the desired state of a Workload.

        :param Sequence['PodGroupArgs'] pod_groups: PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        :param 'TypedLocalObjectReferenceArgs' controller_ref: ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        """
        pulumi.set(__self__, "pod_groups", pod_groups)
        if controller_ref is not None:
            pulumi.set(__self__, "controller_ref", controller_ref)

    @_builtins.property
    @pulumi.getter(name="podGroups")
    def pod_groups(self) -> Sequence['outputs.PodGroup']:
        """
        PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        """
        return pulumi.get(self, "pod_groups")

    @_builtins.property
    @pulumi.getter(name="controllerRef")
    def controller_ref(self) -> Optional['outputs.TypedLocalObjectReference']:
        """
        ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        """
        return pulumi.get(self, "controller_ref")


@pulumi.output_type
class WorkloadSpecPatch(dict):
    """
    WorkloadSpec defines the desired state of a Workload.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "controllerRef":
            suggest = "controller_ref"
        elif key == "podGroups":
            suggest = "pod_groups"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadSpecPatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadSpecPatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadSpecPatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 controller_ref: Optional['outputs.TypedLocalObjectReferencePatch'] = None,
                 pod_groups: Optional[Sequence['outputs.PodGroupPatch']] = None):
        """
        WorkloadSpec defines the desired state of a Workload.

        :param 'TypedLocalObjectReferencePatchArgs' controller_ref: ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        :param Sequence['PodGroupPatchArgs'] pod_groups: PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        """
        if controller_ref is not None:
            pulumi.set(__self__, "controller_ref", controller_ref)
        if pod_groups is not None:
            pulumi.set(__self__, "pod_groups", pod_groups)

    @_builtins.property
    @pulumi.getter(name="controllerRef")
    def controller_ref(self) -> Optional['outputs.TypedLocalObjectReferencePatch']:
        """
        ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        """
        return pulumi.get(self, "controller_ref")

    @_builtins.property
    @pulumi.getter(name="podGroups")
    def pod_groups(self) -> Optional[Sequence['outputs.PodGroupPatch']]:
        """
        PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        """
        return pulumi.get(self, "pod_groups")





# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from ... import _utilities
from ... import meta as _meta

__all__ = [
    'StorageVersionMigrationSpecPatchArgs',
    'StorageVersionMigrationSpecPatchArgsDict',
    'StorageVersionMigrationSpecArgs',
    'StorageVersionMigrationSpecArgsDict',
    'StorageVersionMigrationStatusArgs',
    'StorageVersionMigrationStatusArgsDict',
    'StorageVersionMigrationArgs',
    'StorageVersionMigrationArgsDict',
]

class StorageVersionMigrationSpecPatchArgsDict(TypedDict):
    """
    Spec of the storage version migration.
    """
    resource: NotRequired[pulumi.Input['_meta.v1.GroupResourcePatchArgsDict']]
    """
    The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
    """

@pulumi.input_type
class StorageVersionMigrationSpecPatchArgs:
    def __init__(__self__, *,
                 resource: Optional[pulumi.Input['_meta.v1.GroupResourcePatchArgs']] = None):
        """
        Spec of the storage version migration.

        :param pulumi.Input['_meta.v1.GroupResourcePatchArgs'] resource: The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
        """
        if resource is not None:
            pulumi.set(__self__, "resource", resource)

    @_builtins.property
    @pulumi.getter
    def resource(self) -> Optional[pulumi.Input['_meta.v1.GroupResourcePatchArgs']]:
        """
        The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
        """
        return pulumi.get(self, "resource")

    @resource.setter
    def resource(self, value: Optional[pulumi.Input['_meta.v1.GroupResourcePatchArgs']]):
        pulumi.set(self, "resource", value)


class StorageVersionMigrationSpecArgsDict(TypedDict):
    """
    Spec of the storage version migration.
    """
    resource: pulumi.Input['_meta.v1.GroupResourceArgsDict']
    """
    The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
    """

@pulumi.input_type
class StorageVersionMigrationSpecArgs:
    def __init__(__self__, *,
                 resource: pulumi.Input['_meta.v1.GroupResourceArgs']):
        """
        Spec of the storage version migration.

        :param pulumi.Input['_meta.v1.GroupResourceArgs'] resource: The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
        """
        pulumi.set(__self__, "resource", resource)

    @_builtins.property
    @pulumi.getter
    def resource(self) -> pulumi.Input['_meta.v1.GroupResourceArgs']:
        """
        The resource that is being migrated. The migrator sends requests to the endpoint serving the resource. Immutable.
        """
        return pulumi.get(self, "resource")

    @resource.setter
    def resource(self, value: pulumi.Input['_meta.v1.GroupResourceArgs']):
        pulumi.set(self, "resource", value)


class StorageVersionMigrationStatusArgsDict(TypedDict):
    """
    Status of the storage version migration.
    """
    conditions: NotRequired[pulumi.Input[Sequence[pulumi.Input['_meta.v1.ConditionArgsDict']]]]
    """
    The latest available observations of the migration's current state.
    """
    resource_version: NotRequired[pulumi.Input[_builtins.str]]
    """
    ResourceVersion to compare with the GC cache for performing the migration. This is the current resource version of given group, version and resource when kube-controller-manager first observes this StorageVersionMigration resource.
    """

@pulumi.input_type
class StorageVersionMigrationStatusArgs:
    def __init__(__self__, *,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['_meta.v1.ConditionArgs']]]] = None,
                 resource_version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Status of the storage version migration.

        :param pulumi.Input[Sequence[pulumi.Input['_meta.v1.ConditionArgs']]] conditions: The latest available observations of the migration's current state.
        :param pulumi.Input[_builtins.str] resource_version: ResourceVersion to compare with the GC cache for performing the migration. This is the current resource version of given group, version and resource when kube-controller-manager first observes this StorageVersionMigration resource.
        """
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if resource_version is not None:
            pulumi.set(__self__, "resource_version", resource_version)

    @_builtins.property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['_meta.v1.ConditionArgs']]]]:
        """
        The latest available observations of the migration's current state.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['_meta.v1.ConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @_builtins.property
    @pulumi.getter(name="resourceVersion")
    def resource_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ResourceVersion to compare with the GC cache for performing the migration. This is the current resource version of given group, version and resource when kube-controller-manager first observes this StorageVersionMigration resource.
        """
        return pulumi.get(self, "resource_version")

    @resource_version.setter
    def resource_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_version", value)


class StorageVersionMigrationArgsDict(TypedDict):
    """
    StorageVersionMigration represents a migration of stored data to the latest storage version.
    """
    api_version: NotRequired[pulumi.Input[_builtins.str]]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
    """
    kind: NotRequired[pulumi.Input[_builtins.str]]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
    """
    metadata: NotRequired[pulumi.Input['_meta.v1.ObjectMetaArgsDict']]
    """
    Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    spec: NotRequired[pulumi.Input['StorageVersionMigrationSpecArgsDict']]
    """
    Specification of the migration.
    """
    status: NotRequired[pulumi.Input['StorageVersionMigrationStatusArgsDict']]
    """
    Status of the migration.
    """

@pulumi.input_type
class StorageVersionMigrationArgs:
    def __init__(__self__, *,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input['_meta.v1.ObjectMetaArgs']] = None,
                 spec: Optional[pulumi.Input['StorageVersionMigrationSpecArgs']] = None,
                 status: Optional[pulumi.Input['StorageVersionMigrationStatusArgs']] = None):
        """
        StorageVersionMigration represents a migration of stored data to the latest storage version.

        :param pulumi.Input[_builtins.str] api_version: APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        :param pulumi.Input[_builtins.str] kind: Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        :param pulumi.Input['_meta.v1.ObjectMetaArgs'] metadata: Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        :param pulumi.Input['StorageVersionMigrationSpecArgs'] spec: Specification of the migration.
        :param pulumi.Input['StorageVersionMigrationStatusArgs'] status: Status of the migration.
        """
        if api_version is not None:
            pulumi.set(__self__, "api_version", 'storagemigration.k8s.io/v1beta1')
        if kind is not None:
            pulumi.set(__self__, "kind", 'StorageVersionMigration')
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        """
        return pulumi.get(self, "api_version")

    @api_version.setter
    def api_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_version", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input['_meta.v1.ObjectMetaArgs']]:
        """
        Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input['_meta.v1.ObjectMetaArgs']]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['StorageVersionMigrationSpecArgs']]:
        """
        Specification of the migration.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['StorageVersionMigrationSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['StorageVersionMigrationStatusArgs']]:
        """
        Status of the migration.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['StorageVersionMigrationStatusArgs']]):
        pulumi.set(self, "status", value)


